@@ -1,15 +1,19 @@
 package Path::Router::Route::Match;
+BEGIN {
+  $Path::Router::Route::Match::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Path::Router::Route::Match::VERSION = '0.11';
+}
 use Moose;
-
-our $VERSION   = '0.10';
-our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: The result of a Path::Router match
 
 has 'path'    => (is => 'ro', isa => 'Str',     required => 1);
 has 'mapping' => (is => 'ro', isa => 'HashRef', required => 1);
 
 has 'route'   => (
-    is       => 'ro', 
-    isa      => 'Path::Router::Route', 
+    is       => 'ro',
+    isa      => 'Path::Router::Route',
     required => 1,
     handles  => [qw[target]]
 );
@@ -18,7 +22,7 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose; 1;
 
-__END__
+
 
 =pod
 
@@ -26,13 +30,17 @@ __END__
 
 Path::Router::Route::Match - The result of a Path::Router match
 
+=head1 VERSION
+
+version 0.11
+
 =head1 DESCRIPTION
 
 This is the object returned from calling C<match> on a L<Path::Router>
-instance. It contains all the information you would need to do any 
-dispatching nessecary. 
+instance. It contains all the information you would need to do any
+dispatching nessecary.
 
-=head1 METHODS 
+=head1 METHODS
 
 =over 4
 
@@ -44,8 +52,8 @@ This is the path that was matched.
 
 =item B<mapping>
 
-This is the mapping of your router part names to the actual parts of 
-the path. If your route had no "variables", then this will be an empty 
+This is the mapping of your router part names to the actual parts of
+the path. If your route had no "variables", then this will be an empty
 HASH ref.
 
 =item B<route>
@@ -63,7 +71,7 @@ that was matched.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
@@ -80,4 +88,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
