@@ -1,12 +1,16 @@
 package Path::Router::Shell;
+BEGIN {
+  $Path::Router::Shell::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Path::Router::Shell::VERSION = '0.11';
+}
 use Moose;
+# ABSTRACT: An interactive shell for testing router configurations
 
 use Term::ReadLine;
 use Data::Dumper;
 
-our $VERSION   = '0.10';
-our $AUTHORITY = 'cpan:STEVAN';
-
 has 'router' => (
     is       => 'ro',
     isa      => 'Path::Router',
@@ -15,7 +19,7 @@ has 'router' => (
 
 sub shell {
     my $self = shift;
-    
+
     my $term = Term::ReadLine->new(__PACKAGE__);
     my $OUT = $term->OUT || \*STDOUT;
 
@@ -23,7 +27,7 @@ sub shell {
         chomp;
         return if /[qQ]/;
         my $map = $self->router->match($_);
-        if ($map) {        
+        if ($map) {
             print $OUT Dumper $map;
             print $OUT "Round-trip URI is : " . $self->router->uri_for(%$map),
         }
@@ -36,9 +40,9 @@ sub shell {
 
 __PACKAGE__->meta->make_immutable;
 
-no Moose; 1
+no Moose; 1;
+
 
-__END__
 
 =pod
 
@@ -46,23 +50,27 @@ __END__
 
 Path::Router::Shell - An interactive shell for testing router configurations
 
+=head1 VERSION
+
+version 0.11
+
 =head1 SYNOPSIS
 
   #!/usr/bin/perl
-  
+
   use strict;
   use warnings;
-  
+
   use My::App::Router;
   use Path::Router::Shell;
-  
+
   Path::Router::Shell->new(router => My::App::Router->new)->shell;
 
 =head1 DESCRIPTION
 
-This is a tool for helping test the routing in your applications, so 
-you simply write a small script like showing in the SYNOPSIS and then 
-you can use it to test new routes or debug routing issues, etc etc etc. 
+This is a tool for helping test the routing in your applications, so
+you simply write a small script like showing in the SYNOPSIS and then
+you can use it to test new routes or debug routing issues, etc etc etc.
 
 =head1 METHODS
 
@@ -80,7 +88,7 @@ you can use it to test new routes or debug routing issues, etc etc etc.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
@@ -97,4 +105,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
