@@ -1,17 +1,21 @@
 package Path::Router::Types;
+BEGIN {
+  $Path::Router::Types::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Path::Router::Types::VERSION = '0.11';
+}
 use Moose ();
 use Moose::Util::TypeConstraints;
-
-our $VERSION   = '0.10';
-our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: A set of types that Path::Router uses
 
 class_type 'Moose::Meta::TypeConstraint';
 
 subtype 'Path::Router::Route::ValidationMap'
     => as 'HashRef[Moose::Meta::TypeConstraint]';
-    
+
 # NOTE:
-# canonicalize the route 
+# canonicalize the route
 # validators into a simple
 # set of type constraints
 # - SL
@@ -25,16 +29,16 @@ coerce 'Path::Router::Route::ValidationMap'
                     $orig{$key} = subtype('Str' => where{ /^$val$/ });
                 }
                 else {
-                    $orig{$key} = find_type_constraint($val) 
-                        || Carp::confess "Could not locate type constraint named $val"; 
+                    $orig{$key} = find_type_constraint($val)
+                        || Carp::confess "Could not locate type constraint named $val";
                 }
-            }            
+            }
             return \%orig;
         };
 
 no Moose; no Moose::Util::TypeConstraints; 1;
 
-__END__
+
 
 =pod
 
@@ -42,6 +46,10 @@ __END__
 
 Path::Router::Types - A set of types that Path::Router uses
 
+=head1 VERSION
+
+version 0.11
+
 =head1 SYNOPSIS
 
   use Path::Router::Types;
@@ -50,7 +58,7 @@ Path::Router::Types - A set of types that Path::Router uses
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
@@ -67,4 +75,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
